@@ -8,15 +8,11 @@ import jsii
 import publication
 import typing_extensions
 
-import aws_cdk.aws_ec2._jsii
-import aws_cdk.aws_ecs._jsii
-import aws_cdk.aws_eks._jsii
-import aws_cdk.aws_iam._jsii
-import aws_cdk.core._jsii
+import aws_cdk._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "cdk-gitlab", "1.0.27", __name__[0:-6], "cdk-gitlab@1.0.27.jsii.tgz"
+    "cdk-gitlab", "2.0.95", __name__[0:-6], "cdk-gitlab@2.0.95.jsii.tgz"
 )
 
 __all__ = [
